IndicatorRef

Struct IndicatorRef 

pub struct IndicatorRef {
    pub name: String,
}
Reference to an indicator within a strategy, with convenience methods for building conditions.

Fields

name: String

Implementations

Source

impl IndicatorRef

pub fn new(name: impl Into<String>) -> Self

Create a new indicator reference.

pub fn sma(period: usize) -> Self

SMA convenience constructor.

pub fn ema(period: usize) -> Self

EMA convenience constructor.

pub fn macd(fast: usize, slow: usize, signal: usize) -> Self

MACD convenience constructor.

pub fn macd_signal(fast: usize, slow: usize, signal: usize) -> Self

MACD signal line convenience constructor.

pub fn rsi(period: usize) -> Self

RSI convenience constructor.

pub fn stoch_k(k_period: usize, d_period: usize) -> Self

Stochastic %K convenience constructor.

pub fn stoch_d(k_period: usize, d_period: usize) -> Self

Stochastic %D convenience constructor.

pub fn bb_upper(period: usize, std_dev: f64) -> Self

Bollinger Bands upper convenience constructor.

pub fn bb_middle(period: usize, std_dev: f64) -> Self

Bollinger Bands middle convenience constructor.

pub fn bb_lower(period: usize, std_dev: f64) -> Self

Bollinger Bands lower convenience constructor.

pub fn atr(period: usize) -> Self

ATR convenience constructor.

pub fn volume_sma(period: usize) -> Self

Volume SMA convenience constructor.

pub fn obv() -> Self

OBV convenience constructor.

pub fn pivot_points() -> Self

Pivot Points convenience constructor.

pub fn adx(period: usize) -> Self

ADX convenience constructor.

pub fn wma(period: usize) -> Self

WMA convenience constructor.

pub fn dema(period: usize) -> Self

DEMA convenience constructor.

pub fn tema(period: usize) -> Self

TEMA convenience constructor.

pub fn cci(period: usize) -> Self

CCI convenience constructor.

pub fn williams_r(period: usize) -> Self

Williams %R convenience constructor.

pub fn roc(period: usize) -> Self

ROC convenience constructor.

pub fn stddev(period: usize) -> Self

Standard Deviation convenience constructor.

pub fn crosses_above(self, value: f64) -> ConditionNode

Create a condition: this indicator crosses above a value.

pub fn crosses_above_indicator(self, other: IndicatorRef) -> ConditionNode

Create a condition: this indicator crosses above another indicator.

pub fn crosses_below(self, value: f64) -> ConditionNode

Create a condition: this indicator crosses below a value.

pub fn crosses_below_indicator(self, other: IndicatorRef) -> ConditionNode

Create a condition: this indicator crosses below another indicator.

pub fn is_above(self, value: f64) -> ConditionNode

Create a condition: this indicator is above a value.

pub fn is_above_indicator(self, other: IndicatorRef) -> ConditionNode

Create a condition: this indicator is above another indicator.

pub fn is_below(self, value: f64) -> ConditionNode

Create a condition: this indicator is below a value.

pub fn is_below_indicator(self, other: IndicatorRef) -> ConditionNode

Create a condition: this indicator is below another indicator.

pub fn equals(self, value: f64) -> ConditionNode

Create a condition: this indicator equals a value (within epsilon).

pub fn equals_indicator(self, other: IndicatorRef) -> ConditionNode

Create a condition: this indicator equals another indicator (within epsilon).

pub fn is_between(self, lower: f64, upper: f64) -> ConditionNode

Create a condition: this indicator is between two values.

pub fn is_rising(self, bars: u32) -> ConditionNode

Create a condition: this indicator is rising over bars bars.

pub fn is_falling(self, bars: u32) -> ConditionNode

Create a condition: this indicator is falling over bars bars.

pub fn scaled(self, multiplier: f64) -> ScaledIndicatorRef

Create a condition: this indicator scaled by a multiplier is above a value.